@@ -2,7 +2,7 @@
 Defines classes for interacting with remote data stores.
 
 Currently supported:
-    - HBP Collaboratory v2 seafile storage
+    - EBRAINS Collaboratory v2 seafile storage
     - Swift CSCS storage
     - ModelDB
 
@@ -19,7 +19,7 @@ Other possibilities:
 import os
 import json
 import mimetypes
-
+from warnings import warn
 from pathlib import Path
 from urllib.parse import urlparse
 from urllib.request import urlretrieve
@@ -44,10 +44,8 @@ class FileSystemDataStore(object):
             observation_data = json.load(fp)
 
 
-class CollabV2DataStore(object):
-    """
-    A class for uploading and downloading data from HBP Collaboratory v2 seafile storage.
-    """
+class _CollabDataStore(object):
+    """Base class for data stores that are part of the EBRAINS Collaboratory"""
 
     def __init__(self, collab_id=None, base_folder="/", auth=None, **kwargs):
         self.collab_id = collab_id
@@ -59,10 +57,25 @@ class CollabV2DataStore(object):
     def authorized(self):
         return self._authorized
 
+    def _get_relative_paths(self, file_paths):
+        if isinstance(file_paths, str):
+            file_paths = [file_paths]
+        if len(file_paths) > 1:
+            common_base_dir = os.path.dirname(os.path.commonprefix(file_paths))
+        else:
+            common_base_dir = os.path.dirname(file_paths[0])
+        return [os.path.relpath(p, common_base_dir) for p in file_paths]
+
+
+class CollabDriveDataStore(_CollabDataStore):
+    """
+    A class for uploading and downloading data from EBRAINS Collaboratory Drive storage.
+    """
+
     def authorize(self, auth=None):
         if auth is None:
             auth = self._auth
-        self.client = ebrains_drive.connect(token=auth.token)
+        self.client = ebrains_drive.DriveApiClient(token=auth.token)
         self._authorized = True
         self.repo = self.client.repos.get_repo_by_url(self.collab_id)
 
@@ -72,28 +85,30 @@ class CollabV2DataStore(object):
 
         # make specified base directory
         seafdir_base = self._make_folders(self.base_folder, parent="/")
-
-        if isinstance(file_paths, str):
-            file_paths = [file_paths]
-        if len(file_paths) > 1:
-            common_base_dir = os.path.dirname(os.path.commonprefix(file_paths))
-        else:
-            common_base_dir = os.path.dirname(file_paths[0])
-
-        relative_paths = [os.path.relpath(p, common_base_dir) for p in file_paths]
+        relative_paths = self._get_relative_paths(file_paths)
         uploaded_file_paths = []
         upload_path_prefix = "https://drive.ebrains.eu/lib/" + self.repo.id + "/file"
         for local_path, relative_path in zip(file_paths, relative_paths):
             if os.path.dirname(relative_path):
-                seafdir_parent = self._make_folders(os.path.dirname(relative_path), parent=os.path.join("/", self.base_folder))
-                parent = os.path.join("/", self.base_folder, os.path.dirname(relative_path))
+                seafdir_parent = self._make_folders(
+                    os.path.dirname(relative_path),
+                    parent=os.path.join("/", self.base_folder),
+                )
+                parent = os.path.join(
+                    "/", self.base_folder, os.path.dirname(relative_path)
+                )
             else:
                 parent = os.path.join("/", self.base_folder)
 
             filename = os.path.basename(relative_path)
             seafdir = self.repo.get_dir(parent)
             file_entity = seafdir.upload_local_file(local_path, overwrite=overwrite)
-            uploaded_file_paths.append({"filepath": upload_path_prefix + file_entity.path, "filesize": file_entity.size})
+            uploaded_file_paths.append(
+                {
+                    "filepath": upload_path_prefix + file_entity.path,
+                    "filesize": file_entity.size,
+                }
+            )
             # uploaded_file_paths.append(file_entity._get_download_link()) # this does not work as the link changes with token
         return uploaded_file_paths
 
@@ -128,9 +143,15 @@ class CollabV2DataStore(object):
         if not overwrite:
             # confirm that each target filepath doesn't already exist
             for remote_path in remote_paths:
-                local_path = os.path.join(local_directory, os.path.basename(remote_path))
+                local_path = os.path.join(
+                    local_directory, os.path.basename(remote_path)
+                )
                 if os.path.exists(local_path):
-                    raise FileExistsError("Target file path `{}` already exists!\nSet `overwrite=True` if you wish overwrite existing files!".format(local_path))
+                    raise FileExistsError(
+                        "Target file path `{}` already exists!\nSet `overwrite=True` if you wish overwrite existing files!".format(
+                            local_path
+                        )
+                    )
 
         for remote_path in remote_paths:
             local_path = os.path.join(local_directory, os.path.basename(remote_path))
@@ -151,6 +172,44 @@ class CollabV2DataStore(object):
             return content
 
 
+class CollabBucketDataStore(_CollabDataStore):
+    """
+    A class for uploading and downloading data from EBRAINS Collaboratory Bucket (aka DataProxy) storage.
+    """
+
+    def authorize(self, auth=None):
+        if auth is None:
+            auth = self._auth
+        self.client = ebrains_drive.BucketApiClient(token=auth.token)
+        self._authorized = True
+        self.bucket = self.client.buckets.get_bucket(self.collab_id)
+
+
+    def upload_data(self, file_paths, overwrite=False):
+        if not self.authorized:
+            self.authorize(self._auth)
+
+        if not overwrite:
+            existing_files = self.bucket.ls()
+
+        relative_paths = self._get_relative_paths(file_paths)
+        uploaded_file_paths = []
+        for local_path, relative_path in zip(file_paths, relative_paths):
+            remote_path = os.path.join(self.base_folder, relative_path)
+            if not overwrite:
+                if remote_path in existing_files:
+                    warn(f"File {remote_path} already exists and you have set overwrite=False")
+
+            self.bucket.upload(local_path, remote_path)
+            uploaded_file_paths.append(
+                {
+                    "filepath": f"https://data-proxy.ebrains.eu/api/v1/buckets/{self.collab_id}/{self.base_folder}/{remote_path}",
+                    "filesize": os.stat(local_path).st_size,
+                }
+            )
+        return uploaded_file_paths
+
+
 class HTTPDataStore(object):
     """
     A class for downloading data from the web.
@@ -172,24 +231,34 @@ class HTTPDataStore(object):
             for url in remote_paths:
                 req = requests.head(url)
                 if req.status_code == 200:
-                    if url.startswith("https://senselab.med.yale.edu/modeldb/") and url.endswith("&mime=application/zip"):
-                        filename = req.headers["Content-Disposition"].split("filename=")[1]
+                    if url.startswith(
+                        "https://senselab.med.yale.edu/modeldb/"
+                    ) and url.endswith("&mime=application/zip"):
+                        filename = req.headers["Content-Disposition"].split(
+                            "filename="
+                        )[1]
                     else:
-                        filename = url.split('/')[-1]
+                        filename = url.split("/")[-1]
                 local_path = os.path.join(local_directory, filename)
-                #local_path = os.path.join(local_directory, os.path.basename(urlparse(url).path))
+                # local_path = os.path.join(local_directory, os.path.basename(urlparse(url).path))
                 if os.path.exists(local_path):
-                    raise FileExistsError("Target file path `{}` already exists!\nSet `overwrite=True` if you wish overwrite existing files!".format(local_path))
+                    raise FileExistsError(
+                        "Target file path `{}` already exists!\nSet `overwrite=True` if you wish overwrite existing files!".format(
+                            local_path
+                        )
+                    )
 
         for url in remote_paths:
             req = requests.head(url)
             if req.status_code == 200:
-                if url.startswith("https://senselab.med.yale.edu/modeldb/") and url.endswith("&mime=application/zip"):
+                if url.startswith(
+                    "https://senselab.med.yale.edu/modeldb/"
+                ) and url.endswith("&mime=application/zip"):
                     filename = req.headers["Content-Disposition"].split("filename=")[1]
                 else:
-                    filename = url.split('/')[-1]
+                    filename = url.split("/")[-1]
             local_path = os.path.join(local_directory, filename)
-            #local_path = os.path.join(local_directory, os.path.basename(urlparse(url).path))
+            # local_path = os.path.join(local_directory, os.path.basename(urlparse(url).path))
             Path(os.path.dirname(local_path)).mkdir(parents=True, exist_ok=True)
             filename, headers = urlretrieve(url, local_path)
             local_paths.append(filename)
@@ -213,7 +282,15 @@ class SwiftDataStore(object):
     def __init__(self, **kwargs):
         pass
 
-    def upload_data(self, file_paths, username="", container="", project=None, remote_directory="", overwrite=False):
+    def upload_data(
+        self,
+        file_paths,
+        username="",
+        container="",
+        project=None,
+        remote_directory="",
+        overwrite=False,
+    ):
         try:
             from hbp_archive import Container
         except ImportError:
@@ -233,10 +310,17 @@ class SwiftDataStore(object):
         url_prefix = ""
         if container_obj.public_url:
             url_prefix = container_obj.public_url + "/"
-        remote_paths = container_obj.upload(file_paths, remote_directory=remote_directory, overwrite=overwrite)
+        remote_paths = container_obj.upload(
+            file_paths, remote_directory=remote_directory, overwrite=overwrite
+        )
         uploaded_file_paths = []
         for ind, f in enumerate(file_paths):
-            uploaded_file_paths.append({"filepath": url_prefix + remote_paths[ind], "filesize": os.path.getsize(f)})
+            uploaded_file_paths.append(
+                {
+                    "filepath": url_prefix + remote_paths[ind],
+                    "filesize": os.path.getsize(f),
+                }
+            )
         return uploaded_file_paths
 
     def get_container(self, remote_path, username=""):
@@ -247,14 +331,16 @@ class SwiftDataStore(object):
             return
 
         name_parts = remote_path.split("swift://cscs.ch/")[1].split("/")
-        if name_parts[0].startswith("bp00sp"):  # presuming all project names start like this
+        if name_parts[0].startswith(
+            "bp00sp"
+        ):  # presuming all project names start like this
             prj_name = name_parts[0]
             ind = 1
         else:
             prj_name = None
             ind = 0
         cont_name = name_parts[ind]
-        entity_path = "/".join(name_parts[ind+1:])
+        entity_path = "/".join(name_parts[ind + 1 :])
         pre_path = None
         if not "." in name_parts[-1]:
             dirname = name_parts[-1]
@@ -270,7 +356,9 @@ class SwiftDataStore(object):
             container.project._get_container_info()
         return container, entity_path, pre_path
 
-    def download_data(self, remote_paths, local_directory=".", username="", overwrite=False):
+    def download_data(
+        self, remote_paths, local_directory=".", username="", overwrite=False
+    ):
         if isinstance(remote_paths, str):
             remote_paths = [remote_paths]
         local_paths = []
@@ -278,27 +366,44 @@ class SwiftDataStore(object):
         if not overwrite:
             # confirm that each target filepath doesn't already exist
             for remote_path in remote_paths:
-                local_path = os.path.join(local_directory, os.path.basename(remote_path))
+                local_path = os.path.join(
+                    local_directory, os.path.basename(remote_path)
+                )
                 if os.path.exists(local_path):
-                    raise FileExistsError("Target file path `{}` already exists!\nSet `overwrite=True` if you wish overwrite existing files!".format(local_path))
+                    raise FileExistsError(
+                        "Target file path `{}` already exists!\nSet `overwrite=True` if you wish overwrite existing files!".format(
+                            local_path
+                        )
+                    )
 
         for remote_path in remote_paths:
-            container, entity_path, pre_path = self.get_container(remote_path, username=username)
+            container, entity_path, pre_path = self.get_container(
+                remote_path, username=username
+            )
             contents = container.list()
             contents_match = [x for x in contents if x.name.startswith(entity_path)]
             for item in contents_match:
                 if pre_path:
-                    localdir = os.path.join(local_directory, entity_path.replace(pre_path,"",1))
+                    localdir = os.path.join(
+                        local_directory, entity_path.replace(pre_path, "", 1)
+                    )
                 else:
                     localdir = local_directory
-                if not "directory" in item.content_type: # download files
-                    outpath = container.download(item.name, local_directory=localdir, with_tree=False, overwrite=False)
+                if not "directory" in item.content_type:  # download files
+                    outpath = container.download(
+                        item.name,
+                        local_directory=localdir,
+                        with_tree=False,
+                        overwrite=False,
+                    )
                     if outpath:
                         local_paths.append(outpath)
         return local_paths
 
     def load_data(self, remote_path, username=""):
-        container, entity_path, pre_path = self.get_container(remote_path, username=username)
+        container, entity_path, pre_path = self.get_container(
+            remote_path, username=username
+        )
         content = container.read(entity_path)
         content_type = mimetypes.guess_type(remote_path)[0]
         if content_type == "application/json":
@@ -308,8 +413,8 @@ class SwiftDataStore(object):
 
 
 URI_SCHEME_MAP = {
-    "collabv2": CollabV2DataStore,
+    "collabv2": CollabDriveDataStore,
     "http": HTTPDataStore,
     "https": HTTPDataStore,
-    "swift": SwiftDataStore
+    "swift": SwiftDataStore,
 }
